@@ -10,11 +10,13 @@ typedef int na_shape_t;
 
 #define MAX_VALUE_LENGTH 1024
 
+#define CHECK_ERROR(func) raise_error(func, #func)
+
 // error check
 static void
-check_error(int code)
+raise_error(int code, const char* func)
 {
-  if (code) rb_raise(rb_eRuntimeError, "%s", grib_get_error_message(code));
+  if (code) rb_raise(rb_eRuntimeError, "grib-api function failed:\n  function: %s\n  message: %s", func, grib_get_error_message(code));
 };
 
 
@@ -245,7 +247,7 @@ push_msg_var(var_list **pvar, grib_handle *handle, VALUE file)
 
   len = MAX_VALUE_LENGTH;
   bzero(vname, len);
-  check_error(grib_get_string(handle, "typeOfLevel", vname, &len));
+  CHECK_ERROR(grib_get_string(handle, "typeOfLevel", vname, &len));
   if (strcmp(vname, "unknown")==0 || strcmp(vname,"isobaricInhPa")== 0 || strcmp(vname,"pl")==0)
     strcpy(var_new->ltype, vname);
   else {
@@ -405,7 +407,7 @@ rg_file_initialize(int argc, VALUE *argv, VALUE self)
   grib_handle *handle;
   var_list *var = NULL;
   while ((handle = grib_handle_new_from_file(0, file, &error))) {
-    check_error(error);
+    raise_error(error, "grib_handle_new_from_file(0, file, &error)");
     if (handle == NULL)
       rb_raise(rb_eRuntimeError, "unable to create handle in %s", fname);
     push_msg_var(&var, handle, self);
@@ -673,14 +675,14 @@ rg_message_get_value(int argc, VALUE *argv, VALUE self)
 	  len = MAX_VALUE_LENGTH;
 	  bzero(value, len);
 	  if (grib_get_string(message->handle, name, value, &len) == GRIB_SUCCESS) {
-	    check_error(grib_get_long(message->handle, name, &l));
+	    CHECK_ERROR(grib_get_long(message->handle, name, &l));
 	    if (atol(value) == l)
 	      ret = LONG2NUM(l);
 	    else
 	      ret = rb_str_new2(value);
 	  }
 	} else {
-	  check_error(grib_get_long(message->handle, name, &l));
+	  CHECK_ERROR(grib_get_long(message->handle, name, &l));
 	  ret = LONG2NUM(l);
 	}	  
       } else {
@@ -727,9 +729,9 @@ rg_message_get_data(VALUE self)
   Data_Get_Struct(self, rg_message, message);
   int error;
   grib_iterator *iter = grib_iterator_new(message->handle, 0, &error);
-  check_error(error);
+  raise_error(error, "grib_iterator_new(message->handle, 0, &error);");
   long np;
-  check_error(grib_get_long(message->handle, "numberOfPoints", &np));
+  CHECK_ERROR(grib_get_long(message->handle, "numberOfPoints", &np));
   double *lon, *lat, *value;
   VALUE na_lon, na_lat, na_value;
   struct NARRAY *nary;
@@ -808,4 +810,10 @@ void Init_grib()
 
   rb_define_const(cGrib, "KEYS_ITERATOR_ALL_KEYS", ULONG2NUM(GRIB_KEYS_ITERATOR_ALL_KEYS));
   rb_define_const(cGrib, "KEYS_ITERATOR_SKIP_READ_ONLY", ULONG2NUM(GRIB_KEYS_ITERATOR_SKIP_READ_ONLY));
+
+#ifdef NARRAY_BIGMEM
+  rb_define_const(cGrib, "SUPPORT_BIGMEM", Qtrue);
+#else
+  rb_define_const(cGrib, "SUPPORT_BIGMEM", Qfalse);
+#endif
 }
